// EVIO headers
#include "evioUtil.hxx"
#include "evioFileChannel.hxx"
using namespace evio;

// gemc headers
#include "options.h"
#include "gbank.h"

// C++ headers
#include <string>
#include <iostream>
#include <set>
using namespace std;

// banks header
#include "banks.h"


int main(int argc, char **argv)
{
	// argument is input file name.
	try
	{
		// loading options
		goptions gemcOpt;
		gemcOpt.setGoptions();
		gemcOpt.setOptMap(argc, argv);
		
		double verbosity = gemcOpt.optMap["BANK_VERBOSITY"].arg;
		
		// loading veriables definitions from MYSQL db
		map<string, string> bank_factories;
		bank_factories["flux"] = "MYSQL Original";

		vector<string> whichSystems;
		whichSystems.push_back("flux");
		map<string, gBank> banksMap = read_banks(gemcOpt, bank_factories, whichSystems);

		
		// reading input
		string inputfile = gemcOpt.optMap["INPUTF"].args ;
		evioFileChannel *chan = new evioFileChannel(inputfile, "r", 3000000);
		chan->open();
		while(chan->read())
		{
			evioDOMTree EDT(chan);

			
			readConditions(EDT, verbosity);
			
			// get header bank
			map<string, double> headerBank = getHeaderBank(EDT, getBankFromMap("header", &banksMap), verbosity);

			cout << endl;
		
		
			// read integreated raw and digitized flux hit banks
			for(map<string, gBank>::iterator it = banksMap.begin(); it != banksMap.end(); it++)
			{
				// only considering data banks (bankType.size() > 0) different from "raws"
				if(it->first == "flux" && it->second.idtag != RAWINT_ID)
				{
					// integrated raw data
					getRawIntDataBank(EDT, it->first, &banksMap, verbosity);
					// integrated digitized data
					getDgtIntDataBank(EDT, it->first, &banksMap, verbosity);
					
					
				}
			}
		
		}
		
		
	}
	catch (evioException e)
	{
		cerr << e.toString() << endl;
	}
}
